@@ -918,7 +918,8 @@ func TestImageGetError(t *testing.T) {
 		statuses := []corev1.ConditionStatus{corev1.ConditionFalse, corev1.ConditionTrue, corev1.ConditionTrue, corev1.ConditionTrue, corev1.ConditionFalse, corev1.ConditionFalse, corev1.ConditionFalse}
 		err := h.Handle(event)
 		if !kerrors.IsNotFound(iserr) {
-			statuses[3] = corev1.ConditionUnknown
+			statuses[0] = corev1.ConditionUnknown
+			statuses[3] = corev1.ConditionFalse
 			validate(false, err, "getstreamerror", cfg, conditions, statuses, t)
 		} else {
 			validate(true, err, "", cfg, conditions, statuses, t)
@@ -927,6 +928,27 @@ func TestImageGetError(t *testing.T) {
 
 }
 
+func TestImageUpdateError(t *testing.T) {
+
+	h, cfg, event := setup()
+
+	mimic(&h, x86OCPContentRootDir)
+
+	// process credentials so that check does not short circuit our attempt to validate the template upsert
+	// error logic
+	processCred(&h, cfg, t)
+
+	fakeisclient := h.imageclientwrapper.(*fakeImageStreamClientWrapper)
+	fakeisclient.upserterrors = map[string]error{"foo": kerrors.NewServiceUnavailable("upsertstreamerror")}
+
+	statuses := []corev1.ConditionStatus{corev1.ConditionFalse, corev1.ConditionTrue, corev1.ConditionTrue, corev1.ConditionTrue, corev1.ConditionFalse, corev1.ConditionFalse, corev1.ConditionFalse}
+	err := h.Handle(event)
+	statuses[0] = corev1.ConditionUnknown
+	statuses[3] = corev1.ConditionFalse
+	validate(false, err, "upsertstreamerror", cfg, conditions, statuses, t)
+
+}
+
 func TestImageStreamImportError(t *testing.T) {
 	two := int64(2)
 	one := int64(1)
@@ -1228,7 +1250,7 @@ func TestImageImportRequestCreation(t *testing.T) {
 	}
 }
 
-func TestTemplateGetEreror(t *testing.T) {
+func TestTemplateGetError(t *testing.T) {
 	errors := []error{
 		fmt.Errorf("gettemplateerror"),
 		kerrors.NewNotFound(schema.GroupResource{}, "gettemplateerror"),
@@ -1245,7 +1267,8 @@ func TestTemplateGetEreror(t *testing.T) {
 		statuses := []corev1.ConditionStatus{corev1.ConditionFalse, corev1.ConditionTrue, corev1.ConditionTrue, corev1.ConditionTrue, corev1.ConditionFalse, corev1.ConditionFalse, corev1.ConditionFalse}
 		err := h.Handle(event)
 		if !kerrors.IsNotFound(terr) {
-			statuses[3] = corev1.ConditionUnknown
+			statuses[0] = corev1.ConditionUnknown
+			statuses[3] = corev1.ConditionFalse
 			validate(false, err, "gettemplateerror", cfg, conditions, statuses, t)
 		} else {
 			validate(true, err, "", cfg, conditions, statuses, t)
@@ -1254,6 +1277,25 @@ func TestTemplateGetEreror(t *testing.T) {
 
 }
 
+func TestTemplateUpsertError(t *testing.T) {
+	h, cfg, event := setup()
+
+	mimic(&h, x86OCPContentRootDir)
+
+	// process credentials so that check does not short circuit our attempt to validate the template upsert
+	// error logic
+	processCred(&h, cfg, t)
+
+	faketclient := h.templateclientwrapper.(*fakeTemplateClientWrapper)
+	faketclient.upserterrors = map[string]error{"bo": kerrors.NewServiceUnavailable("upsertstreamerror")}
+
+	statuses := []corev1.ConditionStatus{corev1.ConditionFalse, corev1.ConditionTrue, corev1.ConditionTrue, corev1.ConditionTrue, corev1.ConditionFalse, corev1.ConditionFalse, corev1.ConditionFalse}
+	err := h.Handle(event)
+	statuses[0] = corev1.ConditionUnknown
+	statuses[3] = corev1.ConditionFalse
+	validate(false, err, "upsertstreamerror", cfg, conditions, statuses, t)
+}
+
 func TestDeletedCR(t *testing.T) {
 	h, cfg, event := setup()
 	event.Deleted = true
